# How to contribute

We are happy to include your contribution to this project. To contribute open a pull request and we will get back to you.

## Contributor License Agreement

To clarify the intellectual property license granted with Contributions from any person or entity to HQS, we must have a Contributor License Agreement ("CLA") in place with each contributor. This license is for your protection as a Contributor as well as the protection of HQS and the users of this project; it does not change your rights to use your own Contributions for any other purpose.

Please fill and sign the CLA found in this repository as CLA.pdf and send it to info@quantumsimulations.de.
